package com.zkcloud.eurekaserver;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.Banner;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.netflix.eureka.server.EnableEurekaServer;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;

@EnableEurekaServer
@SpringBootApplication
public class EurekaServerApplication {

    /**
     * 日志
     */
    private static final Logger LOGGER = LoggerFactory.getLogger(EurekaServerApplication.class);

    /**
     * 主入口
     *
     * @param args 参数
     */
    public static void main(String[] args) {
        SpringApplication application = new SpringApplication(EurekaServerApplication.class);
        application.setBannerMode(Banner.Mode.OFF);
        application.run(args);
    }

    /**
     * 应用启动后，输出IoC容器的Beans
     *
     * @param context 上下文
     * @return 匿名类
     */
    @Bean
    public CommandLineRunner springIocCheckList(ApplicationContext context) {
        return args -> {
            for (String bn : context.getBeanDefinitionNames()) {
                LOGGER.debug("SpringBoot Init Bean: " + bn);
            }
            int count = context.getBeanDefinitionCount();
            LOGGER.info("Start Successfully. SpringBoot Init Count: " + count);
        };
    }

}
